package jrummikub.control.network;

import jrummikub.model.GameSettings;
import jrummikub.model.PlayerSettings;
import jrummikub.model.PlayerSettings.Type;
import jrummikub.util.Event;
import jrummikub.util.GameData;
import jrummikub.util.IListener1;
import jrummikub.view.ISettingsPanel.SettingsMode;
import jrummikub.view.IView;

public class GameJoinControl extends AbstractGameBeginControl {
	private Event backEvent = new Event();

	public GameJoinControl(final ConnectionControl connectionControl,
			final GameData gameData, final IView view) {
		super(connectionControl, view, gameData, SettingsMode.NETWORK_JOIN);

		connections.add(connectionControl.getGameOfferEvent().add(
				new IListener1<GameData>() {
					@Override
					public void handle(GameData data) {
						if (data.getGameID().equals(gameData.getGameID())) {
							GameSettings settings = data.getGameSettings();

							fixGameSettings(settings);

							gameData.setGameSettings(settings);

							updateSettingsPanel();
						}
					}
				}));
	}

	private void fixGameSettings(GameSettings settings) {
		for (PlayerSettings player : settings.getPlayerList()) {
			if (player.getType() == Type.HUMAN) {
				player.setType(Type.NETWORK);
			} else if (player.getType() == Type.NETWORK
					&& player.getName().equals(connectionControl.getNickname())) {
				player.setType(Type.HUMAN);
			}
		}
	}

	public Event getBackEvent() {
		return backEvent;
	}

	public void startGameJoin() {
		view.showSettingsPanel(true);
	}

	/**
	 * Aborts joining and goes back to game list
	 */
	protected void goBack() {
		abort();
		connectionControl.leaveGame();
		view.showSettingsPanel(false);
		backEvent.emit();
	}

}
